@@ -47,8 +47,7 @@ class dbmysql:
 
         self.connect()
         
-        if not autocommit:
-            self.__periodic_check()
+        self.__periodic_check()
 
     def __make_where(self, col_names: list, where: dict, inject: str = None):
         where_str = ""
@@ -122,7 +121,7 @@ class dbmysql:
         """
         @elapse 多长时间检测一次
         """
-        if self.__need_commit:
+        if not self.autocommit and self.__need_commit:
             self.commit()
             self.__need_commit = False
         self.update_privilege()
